@@ -1,18 +1,18 @@
 package Complete::Util;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-01-28'; # DATE
-our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.611'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 use Log::ger;
 
 use Complete::Common qw(:all);
-
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-09-08'; # DATE
+our $DIST = 'Complete-Util'; # DIST
+our $VERSION = '0.612'; # VERSION
+
 our @EXPORT_OK = qw(
                        hashify_answer
                        arrayify_answer
@@ -91,6 +91,7 @@ _
 };
 sub hashify_answer {
     my $ans = shift;
+    return unless defined $ans;
     if (ref($ans) ne 'HASH') {
         $ans = {words=>$ans};
     }
@@ -123,6 +124,7 @@ _
 };
 sub arrayify_answer {
     my $ans = shift;
+    return unless defined $ans;
     if (ref($ans) eq 'HASH') {
         $ans = $ans->{words};
     }
@@ -150,6 +152,7 @@ _
 };
 sub answer_num_entries {
     my $ans = shift;
+    return unless defined $ans;
     return ref($ans) eq 'HASH' ? (@{$ans->{words} // []} // 0) : (@$ans // 0);
 }
 
@@ -174,10 +177,11 @@ _
 };
 sub answer_has_entries {
     my $ans = shift;
+    return unless defined $ans;
     return ref($ans) eq 'HASH' ? (@{$ans->{words} // []} ? 1:0) : (@$ans ? 1:0);
 }
 
-sub __min(@) {
+sub __min(@) { ## no critic: Subroutines::ProhibitSubroutinePrototypes
     my $m = $_[0];
     for (@_) {
         $m = $_ if $_ < $m;
@@ -766,7 +770,7 @@ _
 sub combine_answers {
     require List::Util;
 
-    return undef unless @_;
+    return unless @_;
     return $_[0] if @_ < 2;
 
     my $final = {words=>[]};
@@ -914,7 +918,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.611 of Complete::Util (from Perl distribution Complete-Util), released on 2020-01-28.
+This document describes version 0.612 of Complete::Util (from Perl distribution Complete-Util), released on 2022-09-08.
 
 =head1 DESCRIPTION
 
@@ -1385,14 +1389,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-Util>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Complete>
@@ -1408,11 +1404,53 @@ L<Bencher::Scenarios::CompleteUtil>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords A. Sinan Unur Steven Haryanto
+
+=over 4
+
+=item *
+
+A. Sinan Unur <nanis@cpan.org>
+
+=item *
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=back
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-Util>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
